define([
    'jquery',
    'uiComponent',
    'Magento_Ui/js/model/messageList',
    'mage/translate',
    'Magento_Checkout/js/model/full-screen-loader',
    'jquery/jquery.cookie'
], function ($, Component, messageList, $t, fullScreenLoader) {
    'use strict';

    return Component.extend({
        defaults: {
            template: 'WAAVE_Complete/age-check-popup'
        },

        initialize: function(config) {
            this._super();

            this.logoUrl = config.logoUrl;

            this.ageCheckValidateUrl = config.ageCheckValidateUrl;

            this.ageCheckApiKey = config.ageCheckApiKey;

            this.ageCheckStatusUrl = config.ageCheckStatusUrl;

            localStorage.removeItem('age_check_id');
            localStorage.removeItem('verification_status');
            localStorage.removeItem('validation_code');
        },

        getLogo: function() {
            return this.logoUrl;
        },

        showAgeCheckPopup: function () {
            let data = {
                'dob_day'        : $('select#age_check_dob_day').val(),
                'dob_month'      : $('select#age_check_dob_month').val(),
                'dob_year'       : $('select#age_check_dob_year').val(), 
                'age_check_id'   : localStorage.getItem('age_check_id'),
                'validation_code': localStorage.getItem('validation_code')
            };
            let ageCheckApiKey = this.ageCheckApiKey;
            let logoUrl = this.logoUrl;
            let ageCheckStatusUrl = this.ageCheckStatusUrl;
            $.cookie('validation_code', localStorage.getItem('validation_code'));
            $('.age-check-dob-overlay').hide();
            fullScreenLoader.startLoader();
            $.ajax({
                type: 'POST',
                url: this.ageCheckValidateUrl,
                data: data,
                success: function(response) {
                    if (response.success) {
                        if (response.uuid) {
                            fullScreenLoader.stopLoader();
                            (function (w, d, uuid, ageCheckApiKey, logoUrl, ageCheckStatusUrl) {
                                var config = {
                                    mode: "manual",
                                    key: ageCheckApiKey,
                                    show_close: true,
                                    logo_url: logoUrl,
                                    onhide: function () {
                                        if (localStorage.getItem('verification_status') == 'denied') {
                                            $('#agechecker-modal').remove();
                                            $('input').attr("readonly", false).css({"opacity": "unset", "pointer-events": "unset"});
                                            $('body').css('overflow', 'unset');
                                            localStorage.removeItem('age_check_id');
                                            localStorage.removeItem('verification_status');
                                            localStorage.removeItem('validation_code');
                                        } else {
                                            $('#agechecker-modal').remove();
                                            $('input').attr("readonly", false).css({"opacity": "unset", "pointer-events": "unset"});
                                            $('body').css('overflow', 'unset');
                                        }
                                    },
                                    onready: function () {
                                        AgeCheckerAPI.show(uuid);
                                    },
                                    onshow: function () {
                                        var agecheckerFooterStr = ''
                                        + '<div style="display:inline-block;margin-right: 20px;">'
                                        +     'Need help? Email us at <a href="mailto:support@getwaave.com" target="_blank"><span>support@getwaave.com</span></a>'
                                        + '</div>'
                                        + '<div style="display:inline-block;">'
                                        +     '<a href="http://static.getwaave.co/info/tos.html" target="_blank" rel="noopener">Terms of Service & Privacy Policy</a>'
                                        + '</div>';
                                        $('#agechecker #ac-footer').html(agecheckerFooterStr);
                                    },
                                    onstatuschanged: function (verification) {
                                        localStorage.setItem('verification_status', verification.status);
                                        if (verification.status == 'denied') {
                                            $('#agechecker #ac-retry-denied').hide();
                                            $.ajax({
                                                type: 'POST',
                                                url: ageCheckStatusUrl,
                                                data: {
                                                    'age_check_id'   : localStorage.getItem('age_check_id'),
                                                    'validation_code': localStorage.getItem('validation_code')
                                                },
                                                success: function(response) {
                                                },
                                                error: function(response) {
                                                    $('#agechecker #ac-hide-button').show();
                                                }
                                            });
                                        }
                                    },
                                    onclosed: function(done) {
                                        localStorage.removeItem('age_check_id');
                                        localStorage.removeItem('verification_status');
                                        localStorage.removeItem('validation_code');
                                        localStorage.removeItem('checkPostcode');
                                        var event = new CustomEvent('AgeCheckComplete');
                                        d.dispatchEvent(event);
                                    }
                                };
                                w.AgeCheckerConfig = config;
                                if (config.path && (w.location.pathname + w.location.search).indexOf(config.path)) return;
                                var h = d.getElementsByTagName("head")[0];
                                var a = d.createElement("script");
                                a.src = "https://cdn.agechecker.net/static/popup/v1/popup.js";
                                a.crossOrigin = "anonymous";
                                a.onerror = function (a) {
                                    w.location.href = "https://agechecker.net/loaderror";
                                }
                                h.insertBefore(a, h.firstChild);
                            })(window, document, response.uuid, ageCheckApiKey, logoUrl, ageCheckStatusUrl);
                        }
                    }
                },
                error: function(response) {
                    fullScreenLoader.stopLoader();
                    if (response.responseJSON && response.responseJSON.message) {
                        messageList.addErrorMessage({ message: response.responseJSON.message });
                    } else {
                        messageList.addErrorMessage({ message: $t('Validate AgeCheck Compliance Transaction failed') });
                    }
                }
            });
        },

        hideAgeCheckPopup: function() {
            $('.age-check-dob-overlay').hide();
        }
    });
});
