/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
/*browser:true*/
/*global define*/
define(
    [
        'jquery',
        'Magento_Checkout/js/view/payment/default',
        'Magento_Checkout/js/model/quote',
        'Magento_Customer/js/model/customer',
        'Magento_Ui/js/model/messageList',
        'mage/translate',
        'mage/url',
        'Magento_Checkout/js/model/full-screen-loader',
        'Magento_Checkout/js/model/checkout-data-resolver',
        'jquery/jquery.cookie'
    ],
    function ($, Component, quote, customer, messageList, $t, url, fullScreenLoader, checkoutDataResolver) {
        'use strict';

        return Component.extend({
            defaults: {
                template: 'WAAVE_Complete/payment/form',
                redirectAfterPlaceOrder: false
            },

            getCode: function() {
                return 'waave_checkout';
            },

            getData: function() {
                return {
                    'method': this.item.method
                };
            },

            placeOrderCheckoutClick: function() {
                fullScreenLoader.startLoader();
                checkoutDataResolver.resolveBillingAddress();
                checkoutDataResolver.applyBillingAddress();
                const self = this;
                $.ajax({
                    url: url.build('waave_complete/validate/index'),
                    type: 'POST',
                    data: {
                        quoteId: quote.getQuoteId(),
                        guestEmail: customer.customerData.email ? customer.customerData.email : quote.guestEmail,
                        firstName: customer.customerData.firstname ? customer.customerData.firstname : quote.shippingAddress().firstname,
                        lastName: customer.customerData.lastname ? customer.customerData.lastname : quote.shippingAddress().lastname,
                        loggedIn: customer.isLoggedIn,
                        shippingEmail: quote.shippingAddress().email
                    },
                    success: function(response) {
                        if (response.message) {
                            messageList.addErrorMessage({ message: response.message });
                            fullScreenLoader.stopLoader();

                            return false;
                        }
                        
                        if (response.data.age_check_id) {
                            localStorage.setItem('validation_code', response.data.validation_code);
                            localStorage.setItem('age_check_id', response.data.age_check_id);
                            for (let i = 1; i <= 31; i++) {
                                $('.date-input select#age_check_dob_day').append(
                                    `<option value="${i}">${i}</option>`
                                );
                            }
                            let bodMonth = ["Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec"];
                            for (let i = 1; i <= 12; i++) {
                                $('.date-input select#age_check_dob_month').append(
                                    '<option value="' + i + '">' + bodMonth[i - 1] + '</option>'
                                );
                            }
                            const currentYear = new Date().getFullYear();
                            for (let i = currentYear - 18; i >= 1900; i--) {
                                $('.date-input select#age_check_dob_year').append(
                                    `<option value="${i}">${i}</option>`
                                );
                            }
                            $('.age-check-dob-overlay').css({'display': 'block'});
                            fullScreenLoader.stopLoader();
                            document.addEventListener('AgeCheckComplete', function(e) {
                                fullScreenLoader.startLoader();
                                self.placeOrder();
                            });
                        } else {
                            localStorage.removeItem('age_check_id');
                            localStorage.removeItem('verification_status');
                            localStorage.removeItem('validation_code');
                            localStorage.removeItem('checkPostcode');
                            $.cookie('validation_code', response.data.validation_code);
                            self.placeOrder();
                        }
                    },
                    error: function(response) {
                        fullScreenLoader.stopLoader();
                        if (response.responseJSON && response.responseJSON.message) {
                            messageList.addErrorMessage({ message: response.responseJSON.message });
                        } else {
                            messageList.addErrorMessage({ message: $t('Validate Compliance Transaction failed') });
                        }
                    }
                });
            },

            getLogo: function() {
                return window.checkoutConfig.payment.waave_checkout.logo;
            },

            afterPlaceOrder: function() {
                window.location.replace(url.build('waave_complete/checkout/index'));
            }
        });
    }
);