/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
/*browser:true*/
/*global define*/
define(
    [
        'jquery',
        'Magento_Payment/js/view/payment/cc-form',
        'Magento_Checkout/js/model/quote',
        'Magento_Customer/js/model/customer',
        'Magento_Ui/js/model/messageList',
        'mage/translate',
        'mage/url',
        'Magento_Checkout/js/model/full-screen-loader',
        'Magento_Checkout/js/model/checkout-data-resolver',
        'Magento_Payment/js/model/credit-card-validation/validator'
    ],
    function ($, Component, quote, customer, messageList, $t, url, fullScreenLoader, checkoutDataResolver) {
        'use strict';

        return Component.extend({
            defaults: {
                template: 'WAAVE_Complete/payment/form_direct',
                redirectAfterPlaceOrder: false,
                vgsForm: null,
                token: '',
            },

            getCode: function() {
                return 'waave_direct';
            },

            isActive: function() {
                return true;
            },

            hasVerification: function() {
                return true;
            },

            initialize: function() {
                var self = this;

                this._super();
                this.selectPaymentMethod();

                self.vgsForm = VGSCollect.create(
                    window.checkoutConfig.payment.waave_direct.vgs_id,
                    window.checkoutConfig.payment.waave_direct.vgs_env,
                    (state) => {},
                );

                setTimeout(function() {
                    self.vgsForm.field('#cc-number', {
                        type: 'card-number',
                        name: 'card_number',
                        successColor: '#4F8A10',
                        errorColor: '#D8000C',
                        placeholder: 'Credit Card Number',
                        showCardIcon: true,
                        validations: ['required', 'validCardNumber'],
                    });

                    self.vgsForm.field('#cc-expiration-date', {
                        type: 'card-expiration-date',
                        name: 'card_exp',
                        successColor: '#4F8A10',
                        errorColor: '#D8000C',
                        placeholder: 'MM / YY',
                        validations: ['required', 'validCardExpirationDate'],
                    });

                    self.vgsForm.field('#cc-cvc', {
                        type: 'card-security-code',
                        name: 'cvv',
                        successColor: '#4F8A10',
                        errorColor: '#D8000C',
                        placeholder: 'CVC',
                        validations: ['required', 'validCardSecurityCode'],
                    });
                }, 2000);
            },
            placeOrderDirectClick: function() {
                fullScreenLoader.startLoader();
                checkoutDataResolver.resolveBillingAddress();
                checkoutDataResolver.applyBillingAddress();
                const self = this;

                if (self.vgsForm === null) {
                    return false;
                }

                self.vgsForm.submit(
                    "/api/v1/cards/vgs",
                    {},
                    (status, response) => {
                        if (status === 200) {
                            self.token = response.card_token;

                            $.ajax({
                                url: url.build('waave_complete/validate/index'),
                                type: 'POST',
                                data: {
                                    quoteId: quote.getQuoteId(),
                                    guestEmail: customer.customerData.email ? customer.customerData.email : quote.guestEmail,
                                    firstName: customer.customerData.firstname ? customer.customerData.firstname : quote.shippingAddress().firstname,
                                    lastName: customer.customerData.lastname ? customer.customerData.lastname : quote.shippingAddress().lastname,
                                    loggedIn: customer.isLoggedIn,
                                    shippingEmail: quote.shippingAddress().email
                                },
                                success: function(response) {
                                    if (response.message) {
                                        messageList.addErrorMessage({ message: response.message });
                                        fullScreenLoader.stopLoader();
            
                                        return false;
                                    }
                                    
                                    if (response.data.age_check_id) {
                                        localStorage.setItem('validation_code', response.data.validation_code);
                                        localStorage.setItem('age_check_id', response.data.age_check_id);
                                        for (let i = 1; i <= 31; i++) {
                                            $('.date-input select#age_check_dob_day').append(
                                                `<option value="${i}">${i}</option>`
                                            );
                                        }
                                        let bodMonth = ["Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec"];
                                        for (let i = 1; i <= 12; i++) {
                                            $('.date-input select#age_check_dob_month').append(
                                                '<option value="' + i + '">' + bodMonth[i - 1] + '</option>'
                                            );
                                        }
                                        const currentYear = new Date().getFullYear();
                                        for (let i = currentYear - 18; i >= 1900; i--) {
                                            $('.date-input select#age_check_dob_year').append(
                                                `<option value="${i}">${i}</option>`
                                            );
                                        }
                                        $('.age-check-dob-overlay').css({'display': 'block'});
                                        fullScreenLoader.stopLoader();
                                        document.addEventListener('AgeCheckComplete', function(e) {
                                            fullScreenLoader.startLoader();
                                            self.placeOrder();
                                        });
                                    } else {
                                        localStorage.removeItem('age_check_id');
                                        localStorage.removeItem('verification_status');
                                        localStorage.removeItem('validation_code');
                                        localStorage.removeItem('checkPostcode');
                                        self.placeOrder();
                                    }
                                },
                                error: function(response) {
                                    fullScreenLoader.stopLoader();
                                    if (response.responseJSON && response.responseJSON.message) {
                                        messageList.addErrorMessage({ message: response.responseJSON.message });
                                    } else {
                                        messageList.addErrorMessage({ message: $t('Validate Compliance Transaction failed') });
                                    }
                                }
                            });
                        } else {
                            messageList.addErrorMessage({ message: response.message });
                            fullScreenLoader.stopLoader();

                            return false;
                        }
                    },
                    (errors) => {
                        messageList.addErrorMessage({ message: $t('Please check your credit card information again') });
                        fullScreenLoader.stopLoader();

                        return false;
                    },
                );
            },

            getLogo: function() {
                return window.checkoutConfig.payment.waave_direct.logo;
            },

            afterPlaceOrder: function() {
                window.location.replace(url.build('waave_complete/direct/index') + '?token=' + this.token);
            }
        });
    }
);