<?php

namespace WAAVE\Compliance\Block\Adminhtml;

use Magento\Backend\Block\Template\Context;
use WAAVE\Compliance\Model\ConfigurationFactory;
use Magento\Framework\UrlInterface;
use WAAVE\ComplianceRegX\Helper\Api;

class Configuration extends \Magento\Backend\Block\Template
{
    const API_KEY_GOOGLE_FONT = 'AIzaSyAZnNr3PX2QGG349vh1CXlZ-H9fND82dbo';
    protected $_configurationFactory;
    protected $_urlInterface;
    protected $apiHelper;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     */
    public function __construct(
        Context $context,
        ConfigurationFactory $configurationFactory,
        UrlInterface $urlInterface
    ) {
        parent::__construct($context);
        $this->_configurationFactory = $configurationFactory;
        $this->_urlInterface = $urlInterface;
        $this->apiHelper = new Api;
    }

    /**
     * Prepares layout
     *
     * @return \Magento\Framework\View\Element\AbstractBlock
     */
    protected function _prepareLayout()
    {
        $this->getToolbar()->addChild(
            'save_button',
            \Magento\Backend\Block\Widget\Button::class,
            [
                'label' => __('Save Config'),
                'class' => 'save primary',
                'data_attribute' => [
                    'mage-init' => ['button' => ['event' => 'save', 'target' => '#configuration-form']],
                ]
            ]
        );

        return parent::_prepareLayout();
    }

    /**
     * Returns URL for save action
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getFormActionUrl()
    {
        return $this->getUrl('/*/save');
    }

    /**
     * Returns access key for save action
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getAccessKey()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('access_key');
    }

    /**
     * Returns private key for save action
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getPrivateKey()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('private_key');
    }

    /**
     * Returns Venue ID for save action
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getVenueID()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('venue_id');
    }

    /**
     * Returns password for save action
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getPassword()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('password');
    }

    /**
     * Get test mode
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getTestMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('test_mode');
    }

    /**
     * Get age gate mode
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGateMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_mode');
    }

    /**
     * Get disclaimers mode
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getDisclaimersMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('disclaimers_mode');
    }

    /**
     * Get footer mode
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getFooterMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_mode');
    }

    /**
     * Get footer background color
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getFooterBackgroundColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_background_color');
    }

    /**
     * Get footer color
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getFooterColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_color');
    }

    /**
     * Get age gate popup design mode
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupDesignMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_design_mode');
    }

    /**
     * Get age gate popup size
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupSize()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_size');
    }

    /**
     * Get age gate popup width
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupWidth()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_width');
    }

    /**
     * Get age gate popup height
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupHeight()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_height');
    }

    /**
     * Get age gate popup background color
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupBackgroundColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_background_color');
    }

    /**
     * Get age gate popup color
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_color');
    }

    /**
     * Get age gate popup button color
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupButtonColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_button_color');
    }

    /**
     * Get age gate popup button color default
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupButtonColorDefault()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_button_color_default');
    }

    /**
     * Get age gate popup logo
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupLogo()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo');
    }

    /**
     * Get age gate popup logo default
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupLogoDefault()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_default');
    }

    /**
     * Preview age gate popup popup logo
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function previewAgeGatePopupLogo()
    {
        $configuration = $this->getConfiguration();
        $imgUrl = $configuration->getData('age_gate_popup_logo') ? $this->_urlInterface->getBaseUrl() . 'pub/media/age_gate_popup_logo/' . $configuration->getData('age_gate_popup_logo') : $this->getViewFileUrl('WAAVE_Compliance::images/no-image.png');
        return $imgUrl;
    }
    
    /**
     * Get age gate popup logo width
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupLogoWidth()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_width');
    }

    /**
     * Get age gate popup logo height
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupLogoHeight()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_height');
    }

    /**
     * Get font families
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getFontFamilies()
    {
        $response = $this->apiHelper->makeGetRequest('https://www.googleapis.com/webfonts/v1/webfonts?key=' . self::API_KEY_GOOGLE_FONT);
        return $response['items'];
    }

    /**
     * Get age gate popup font size
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupFontSize()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_size');
    }

    /**
     * Get age gate popup font family type
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupFontFamilyType()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_family_type');
    }

    /**
     * Get age gate popup google font
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupGoogleFont()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_google_font');
    }

    /**
     * Get age gate popup font family
     * 
     * @return string
     * @codeCoverageIgnore
     */
    public function getAgeGatePopupFontFamily()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_family');
    }

    /**
     * Returns URL for delete image
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getDeleteImageUrl()
    {
        return $this->getUrl('/*/deleteImage');
    }

    /**
     * Returns configuration
     *
     * @return object
     * @codeCoverageIgnore
     */
    protected function getConfiguration()
    {
        $collection = $this->_configurationFactory->create()->getCollection();
        return $collection->getFirstItem();
    }
}