<?php

namespace WAAVE\Compliance\Block;

use WAAVE\Compliance\Model\ConfigurationFactory;
use WAAVE\Compliance\Helper\Domain;
use WAAVE\Compliance\Helper\Api;

class AgeGatePopup extends \Magento\Framework\View\Element\Template
{
    protected $_configurationFactory;
    protected $domainHelper;
    protected $apiHelper;

    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        ConfigurationFactory $configurationFactory
    ) {
        parent::__construct($context);

        $this->_configurationFactory = $configurationFactory;
        $this->domainHelper = new Domain;
        $this->apiHelper = new Api;
    }

    public function getAgeGateMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_mode');
    }

    public function getVenueID()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('venue_id');
    }

    public function getTestMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('test_mode');
    }

    public function getDataPopup()
    {
        $content = '';
        $url = $this->domainHelper->getDomain($this->getTestMode()) . '/compliance/categories/age-gate/' . $this->getVenueID();
        $response = $this->apiHelper->makeGetRequest($url);
        if (isset($response['client_logo'])) {
            $ava = $response['client_logo']['original'];
        } else {
            $ava = $this->domainHelper->getDomain($this->getTestMode()) . '/images/no-image.png';
        }

        if (isset($response['data'])) {
            foreach ($response['data'] as $vertical) {
                $content .= 'You must be ' . $vertical['age'] . '+ to purchase ' . $vertical['label'] . ' products<br>';
            }
        }

        return [
            'ava' => $ava,
            'content' => $content
        ];
    }

    public function getAgeGatePopupDesignMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_design_mode');
    }

    public function getAgeGatePopupSize()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_size');
    }

    public function getAgeGatePopupWidth()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_width');
    }

    public function getAgeGatePopupHeight()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_height');
    }

    public function getAgeGatePopupBackgroundColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_background_color');
    }

    public function getAgeGatePopupColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_color');
    }

    public function getAgeGatePopupButtonColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_button_color');
    }

    public function getAgeGatePopupFontSize()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_size');
    }

    public function getAgeGatePopupLogo()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo');
    }

    public function getAgeGatePopupLogoDefault()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_default');
    }

    public function getAgeGatePopupLogoWidth()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_width');
    }

    public function getAgeGatePopupLogoHeight()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_logo_height');
    }

    public function getAgeGatePopupFontFamilyType()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_family_type');
    }

    public function getAgeGatePopupGoogleFont()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_google_font');
    }

    public function getAgeGatePopupFontFamily()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('age_gate_popup_font_family');
    }

    /**
     * Returns configuration
     *
     * @return object
     * @codeCoverageIgnore
     */
    protected function getConfiguration()
    {
        $collection = $this->_configurationFactory->create()->getCollection();
        return $collection->getFirstItem();
    }
}