<?php

namespace WAAVE\Compliance\Block;

use WAAVE\Compliance\Model\ConfigurationFactory;
use WAAVE\Compliance\Helper\Domain;
use WAAVE\Compliance\Helper\Api;

class Logo extends \Magento\Framework\View\Element\Template
{
    /**
     * @var Magento\Framework\View\Asset\Repository
     */
    private $assetRepository;
    protected $_configurationFactory;
    protected $domainHelper;
    protected $apiHelper;

    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \Magento\Framework\View\Asset\Repository $assetRepository,
        ConfigurationFactory $configurationFactory
    ) {
        parent::__construct($context);

        $this->assetRepository = $assetRepository;
        $this->_configurationFactory = $configurationFactory;
        $this->domainHelper = new Domain;
        $this->apiHelper = new Api;
    }

    public function getLogo()
    {
        $logo = $this->assetRepository->getUrlWithParams('WAAVE_Compliance::images/WaaveCompliace_Trust_Seal.png', []);

        return $logo;
    }

    public function getDisclaimersMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('disclaimers_mode');
    }

    public function getFooterMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_mode');
    }

    public function getFooterBackgroundColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_background_color');
    }

    public function getFooterColor()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('footer_color');
    }

    public function getVenueID()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('venue_id');
    }

    public function getTestMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('test_mode');
    }

    public function getDisclaimers()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('disclaimer');
    }

    /**
     * Returns configuration
     *
     * @return object
     * @codeCoverageIgnore
     */
    protected function getConfiguration()
    {
        $collection = $this->_configurationFactory->create()->getCollection();
        return $collection->getFirstItem();
    }
}