<?php

namespace WAAVE\Compliance\Controller\Adminhtml\Configuration;

use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Magento\Backend\App\Action\Context;
use WAAVE\Compliance\Controller\Adminhtml\Configuration;
use WAAVE\Compliance\Model\ConfigurationFactory;
use Magento\MediaStorage\Model\File\UploaderFactory;
use Magento\Framework\Image\AdapterFactory;
use Magento\Framework\Filesystem;
use Magento\Framework\App\Filesystem\DirectoryList;

class Save extends Configuration implements HttpPostActionInterface
{
    const PROD_URL = 'https://getwaave.co/compliance/active';
    const STAG_URL = 'https://staging.getwaave.co/compliance/active';

    protected $_configurationFactory;
    protected $_uploaderFactory;
    protected $_adapterFactory;
    protected $_filesystem;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \WAAVE\Compliance\Model\ConfigurationFactory $configurationFactory
     * @param \Magento\MediaStorage\Model\File\UploaderFactory $uploaderFactory
     * @param \Magento\Framework\Image\AdapterFactory $adapterFactory
     * @param \Magento\Framework\Filesystem $filesystem
     */
    public function __construct(
        Context $context,
        ConfigurationFactory $configurationFactory,
        UploaderFactory $uploaderFactory,
        AdapterFactory $adapterFactory,
        Filesystem $filesystem
    ) {
        parent::__construct($context);
        $this->_configurationFactory = $configurationFactory;
        $this->_uploaderFactory = $uploaderFactory;
        $this->_adapterFactory = $adapterFactory;
        $this->_filesystem = $filesystem;
    }

    /**
     * Save configuration
     *
     * @return ResultInterface
     */
    public function execute()
    {
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();

        $ageGateMode = $this->getRequest()->getParam('age_gate_mode') ? 1 : 0;
        $disclaimersMode = $this->getRequest()->getParam('disclaimers_mode') ? 1 : 0;
        $footerMode = $this->getRequest()->getParam('footer_mode') ? 1 : 0;
        $footerBackgroundColor = $this->getRequest()->getParam('footer_background_color');
        $footerColor = $this->getRequest()->getParam('footer_color');
        $ageGatePopupDesignMode = $this->getRequest()->getParam('age_gate_popup_design_mode') ? 1 : 0;
        if ($ageGatePopupDesignMode) {
            $ageGatePopupSize = $this->getRequest()->getParam('age_gate_popup_size');
            $ageGatePopupWidth = $this->getRequest()->getParam('age_gate_popup_width');
            $ageGatePopupWidth = !empty($ageGatePopupWidth) ? $ageGatePopupWidth : null;
            $ageGatePopupHeight = $this->getRequest()->getParam('age_gate_popup_height');
            $ageGatePopupHeight = !empty($ageGatePopupHeight) ? $ageGatePopupHeight : null;
            $ageGatePopupBackgroundColor = $this->getRequest()->getParam('age_gate_popup_background_color');
            $ageGatePopupColor = $this->getRequest()->getParam('age_gate_popup_color');
            $ageGatePopupButtonColorDefault = $this->getRequest()->getParam('age_gate_popup_button_color_default') ? 1 : 0;
            if (!$ageGatePopupButtonColorDefault) {
                $ageGatePopupButtonColor = $this->getRequest()->getParam('age_gate_popup_button_color');
            } else {
                $ageGatePopupButtonColor = null;
            }
            try{
                if ($this->getRequest()->getFiles('age_gate_popup_logo') && $this->getRequest()->getFiles('age_gate_popup_logo')['size'] > 0) {
                    $uploaderFactory = $this->_uploaderFactory->create(['fileId' => 'age_gate_popup_logo']);
                    $uploaderFactory->setAllowedExtensions(['jpg', 'jpeg', 'gif', 'png']);
                    $imageAdapter = $this->_adapterFactory->create();
                    $uploaderFactory->addValidateCallback('custom_image_upload', $imageAdapter, 'validateUploadFile');
                    $uploaderFactory->setAllowRenameFiles(true);
                    $uploaderFactory->setFilesDispersion(true);
                    $mediaDirectory = $this->_filesystem->getDirectoryRead(DirectoryList::MEDIA);
                    $destinationPath = $mediaDirectory->getAbsolutePath('age_gate_popup_logo');
                    $result = $uploaderFactory->save($destinationPath);
                    if (!$result) {
                        $this->messageManager->addErrorMessage(__('File can not be saved to path: $1', $destinationPath));
                        return $resultRedirect->setPath('waave_compliance/*/');
                    }
                    $ageGatePopupLogo = ltrim($result['file'], '/');
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
                return $resultRedirect->setPath('waave_compliance/*/');
            }
            $ageGatePopupLogoDefault = $this->getRequest()->getParam('age_gate_popup_logo_default') ? 1 : 0;
            $ageGatePopupLogoWidth = $this->getRequest()->getParam('age_gate_popup_logo_width');
            $ageGatePopupLogoWidth = !empty($ageGatePopupLogoWidth) ? $ageGatePopupLogoWidth : null;
            $ageGatePopupLogoHeight = $this->getRequest()->getParam('age_gate_popup_logo_height');
            $ageGatePopupLogoHeight = !empty($ageGatePopupLogoHeight) ? $ageGatePopupLogoHeight : null;
            $ageGatePopupFontSize = $this->getRequest()->getParam('age_gate_popup_font_size');
            $ageGatePopupFontFamilyType = $this->getRequest()->getParam('age_gate_popup_font_family_type');
            if ($ageGatePopupFontFamilyType == '') {
                $ageGatePopupFontFamily = null;
                $ageGatePopupGoogleFont = null;
            } elseif ($ageGatePopupFontFamilyType == 'google_font') {
                $ageGatePopupGoogleFont = $this->getRequest()->getParam('age_gate_popup_google_font');
                $ageGatePopupFontFamily = null;
            } else {
                $ageGatePopupGoogleFont = null;
                $ageGatePopupFontFamily= str_replace('"', '', $this->getRequest()->getParam('age_gate_popup_font_family'));
            }
        } else {
            $ageGatePopupSize = null;
            $ageGatePopupWidth = null;
            $ageGatePopupHeight = null;
            $ageGatePopupBackgroundColor = null;
            $ageGatePopupColor = null;
            $ageGatePopupButtonColorDefault = 1;
            $ageGatePopupButtonColor = null;
            $ageGatePopupLogo = null;
            $ageGatePopupLogoDefault = 1;
            $ageGatePopupLogoWidth = null;
            $ageGatePopupLogoHeight = null;
            $ageGatePopupFontSize = null;
            $ageGatePopupFontFamilyType = null;
            $ageGatePopupFontFamily = null;
            $ageGatePopupGoogleFont = null;
        }
        $accessKey  = $this->getRequest()->getParam('access_key', null);
        $privateKey = $this->getRequest()->getParam('private_key', null);
        $venueId    = $this->getRequest()->getParam('venue_id', null);
        $password   = $this->getRequest()->getParam('password', null);
        $testMode   = $this->getRequest()->getParam('test_mode', 1);

        $collection = $this->_configurationFactory->create()->getCollection();
        $configuration = $collection->getFirstItem();

        if (!isset($ageGatePopupLogo)) {
            $ageGatePopupLogo = $configuration->getAgeGatePopupLogo();
        }

        $configuration->setAgeGateMode($ageGateMode);
        $configuration->setDisclaimersMode($disclaimersMode);
        $configuration->setFooterMode($footerMode);
        $configuration->setFooterBackgroundColor($footerBackgroundColor);
        $configuration->setFooterColor($footerColor);
        $configuration->setAgeGatePopupDesignMode($ageGatePopupDesignMode);
        $configuration->setAgeGatePopupSize($ageGatePopupSize);
        $configuration->setAgeGatePopupWidth($ageGatePopupWidth);
        $configuration->setAgeGatePopupHeight($ageGatePopupHeight);
        $configuration->setAgeGatePopupBackgroundColor($ageGatePopupBackgroundColor);
        $configuration->setAgeGatePopupColor($ageGatePopupColor);
        $configuration->setAgeGatePopupButtonColor($ageGatePopupButtonColor);
        $configuration->setAgeGatePopupButtonColorDefault($ageGatePopupButtonColorDefault);
        $configuration->setAgeGatePopupLogo($ageGatePopupLogo);
        $configuration->setAgeGatePopupLogoDefault($ageGatePopupLogoDefault);
        $configuration->setAgeGatePopupLogoWidth($ageGatePopupLogoWidth);
        $configuration->setAgeGatePopupLogoHeight($ageGatePopupLogoHeight);
        $configuration->setAgeGatePopupFontSize($ageGatePopupFontSize);
        $configuration->setAgeGatePopupFontFamilyType($ageGatePopupFontFamilyType);
        $configuration->setAgeGatePopupGoogleFont($ageGatePopupGoogleFont);
        $configuration->setAgeGatePopupFontFamily($ageGatePopupFontFamily);
        $configuration->setAccessKey($accessKey);
        $configuration->setPrivateKey($privateKey);
        $configuration->setVenueId($venueId);
        $configuration->setPassword($password);
        $configuration->setTestMode($testMode);
        $configuration->save();

        try {
            $versionApi  = $this->_url->getBaseUrl() . 'rest/V1/waave-compliance/version';
            $productApi  = $this->_url->getBaseUrl() . 'rest/V1/waave-compliance/products';
            $categoryApi = $this->_url->getBaseUrl() . 'rest/V1/waave-compliance/categories';
            $disclaimerSyncApi = $this->_url->getBaseUrl() . 'rest/V1/waave-compliance/disclaimer/sync';

            $params = array(
                'version'             => '2.1.2',
                'venue_id'            => $configuration->getVenueId(),
                'password'            => $configuration->getPassword(),
                'ping_url'            => $versionApi,
                'category_url'        => $categoryApi,
                'menu_item_url'       => $productApi,
                'disclaimer_sync_url' => $disclaimerSyncApi
            );

            $url = self::PROD_URL;
            if ($testMode) {
                $url = self::STAG_URL;
            }

            $client = new \GuzzleHttp\Client();
            $client->request('POST', $url, [
                'form_params' => $params
            ]);

            $this->messageManager->addSuccessMessage(__('Your configurations saved successfully. Please go to System > Cache Management and click "Flush Magento Cache" to clear cache'));

        } catch (\Exception $e) {
            $this->messageManager->addWarningMessage(json_decode($e->getResponse()->getBody()->getContents())->message);
        }

        return $resultRedirect->setPath('waave_compliance/*/');
    }
}