<?php

namespace WAAVE\Compliance\Model;

use Psr\Log\LoggerInterface;
use WAAVE\Compliance\Model\ConfigurationFactory;
use WAAVE\Compliance\Helper\Domain;
use WAAVE\Compliance\Helper\Api;

class DisclaimerManagement
{
    protected $logger;
    protected $configurationFactory;
    protected $domainHelper;
    protected $apiHelper;

    public function __construct(
        LoggerInterface $logger,
        ConfigurationFactory $configurationFactory
    ) {
        $this->logger = $logger;
        $this->configurationFactory = $configurationFactory;
        $this->domainHelper = new Domain;
        $this->apiHelper = new Api;
    }

    /**
     * @inheritdoc
     */
    public function syncDisclaimer()
    {
        try {
            $disclaimers = 'Disclaimer: ';
            $url = $this->domainHelper->getDomain($this->getTestMode()) . '/compliance/categories/age-gate/' . $this->getVenueID();
            $response = $this->apiHelper->makeGetRequest($url);
            foreach ($response['data'] as $vertical) {
                if ($vertical['disclaimer']) {
                    $disclaimers = $disclaimers . $vertical['disclaimer'] . '&nbsp;';
                }
            }

            $configuration = $this->getConfiguration();
            $configuration->setDisclaimer($disclaimers);
            $configuration->save();

            return json_encode([
                'success' => true
            ]);
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
            
            return json_encode([
                'success' => false,
                'message' => $e->getMessage()
            ]);
        }
    }

    public function getTestMode()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('test_mode');
    }

    public function getVenueID()
    {
        $configuration = $this->getConfiguration();
        return $configuration->getData('venue_id');
    }

    protected function getConfiguration()
    {
        $collection = $this->configurationFactory->create()->getCollection();
        return $collection->getFirstItem();
    }
}