<?php

namespace WAAVE\Compliance\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * @inheritdoc
     * @SuppressWarnings(PHPMD.ExcessiveMethodLength)
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        if (!$setup->tableExists('waave_compliance_configuration')) {
            $setup->startSetup();
            $table = $setup->getConnection()
                ->newTable($setup->getTable('waave_compliance_configuration'))
                ->addColumn(
                    'entity_id',
                    Table::TYPE_INTEGER,
                    null,
                    [
                        'identity' => true,
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true
                    ],
                    'Entity ID'
                )
                ->addColumn(
                    'access_key',
                    Table::TYPE_TEXT,
                    null,
                    [
                        'nullable' => false
                    ],
                    'Access Key'
                )
                ->addColumn(
                    'private_key',
                    Table::TYPE_TEXT,
                    null,
                    [
                        'nullable' => false
                    ],
                    'Private Key'
                )
                ->addColumn(
                    'venue_id',
                    Table::TYPE_TEXT,
                    null,
                    [
                        'nullable' => false
                    ],
                    'Venue ID'
                )
                ->addColumn(
                    'password',
                    Table::TYPE_TEXT,
                    null,
                    [
                        'nullable' => false
                    ],
                    'Password'
                )
                ->addColumn(
                    'test_mode',
                    Table::TYPE_SMALLINT,
                    null,
                    [
                        'nullable' => false
                    ],
                    'Test Mode'
                )
                ->setComment('WAAVE Compliance configuration');

            $setup->getConnection()->createTable($table);
            $setup->endSetup();
        }

        if(version_compare($context->getVersion(), '2.1.0', '<')) {
            $setup->startSetup();
            $setup->getConnection()
            ->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_mode',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 0,
                    'comment' => 'Age Gate Mode'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'disclaimers_mode',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 0,
                    'comment' => 'Disclaimers Mode'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'footer_mode',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 0,
                    'comment' => 'Footer Mode'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'footer_background_color',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Footer Background Color'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'footer_color',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Footer Color'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'disclaimer',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Disclaimer'
                ]
            );
            $setup->endSetup();
        }

        if(version_compare($context->getVersion(), '2.1.2', '<')) {
            $setup->startSetup();
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_design_mode',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 0,
                    'comment' => 'Age Gate Popup Design Mode'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_size',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Size'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_width',
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Width'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_height',
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Height'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_background_color',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Background Color'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_color',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Color'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_logo',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Logo'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_logo_default',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 1,
                    'comment' => 'Age Gate Popup Logo Default'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_logo_width',
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Logo Width'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_logo_height',
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Logo Height'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_font_size',
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Font Size'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_font_family_type',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Font Family Type'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_google_font',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Google Font'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_font_family',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Font Family'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_button_color',
                [
                    'type' => Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Age Gate Popup Button Color'
                ]
            );
            $setup->getConnection()->addColumn(
                $setup->getTable('waave_compliance_configuration'),
                'age_gate_popup_button_color_default',
                [
                    'type' => Table::TYPE_SMALLINT,
                    'length' => 1,
                    'nullable' => true,
                    'default' => 1,
                    'comment' => 'Age Gate Popup Button Color Default'
                ]
            );
            $setup->endSetup();
        }
    }
}
